@@ -1,35 +1,49 @@
 package Encode::Encoding;
+
 # Base class for classes which implement encodings
 use strict;
-our $VERSION = do { my @r = (q$Revision: 2.1 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = ( q$Revision: 2.3 $ =~ /\d+/g ); sprintf "%d." . "%02d" x $#r, @r };
 
 require Encode;
 
-sub Define
-{
-    my $obj = shift;
+sub DEBUG { 0 }
+
+sub Define {
+    my $obj       = shift;
     my $canonical = shift;
-    $obj = bless { Name => $canonical },$obj unless ref $obj;
+    $obj = bless { Name => $canonical }, $obj unless ref $obj;
+
     # warn "$canonical => $obj\n";
-    Encode::define_encoding($obj, $canonical, @_);
+    Encode::define_encoding( $obj, $canonical, @_ );
 }
 
-sub name  { return shift->{'Name'} }
+sub name { return shift->{'Name'} }
+
+# sub renew { return $_[0] }
+
+sub renew {
+    my $self = shift;
+    my $clone = bless {%$self} => ref($self);
+    $clone->{renewed}++;    # so the caller can see it
+    DEBUG and warn $clone->{renewed};
+    return $clone;
+}
+
+sub renewed { return $_[0]->{renewed} || 0 }
 
-sub renew { return $_[0] }
 *new_sequence = \&renew;
 
-sub needs_lines { 0 };
+sub needs_lines { 0 }
 
-sub perlio_ok { 
-    eval{ require PerlIO::encoding };
+sub perlio_ok {
+    eval { require PerlIO::encoding };
     return $@ ? 0 : 1;
 }
 
 # (Temporary|legacy) methods
 
-sub toUnicode    { shift->decode(@_) }
-sub fromUnicode  { shift->encode(@_) }
+sub toUnicode   { shift->decode(@_) }
+sub fromUnicode { shift->encode(@_) }
 
 #
 # Needs to be overloaded or just croak
@@ -39,17 +53,17 @@ sub encode {
     require Carp;
     my $obj = shift;
     my $class = ref($obj) ? ref($obj) : $obj;
-    Carp::croak($class . "->encode() not defined!");
+    Carp::croak( $class . "->encode() not defined!" );
 }
 
-sub decode{
+sub decode {
     require Carp;
     my $obj = shift;
     my $class = ref($obj) ? ref($obj) : $obj;
-    Carp::croak($class . "->encode() not defined!");
+    Carp::croak( $class . "->encode() not defined!" );
 }
 
-sub DESTROY {}
+sub DESTROY { }
 
 1;
 __END__
@@ -167,25 +181,29 @@ MUST return the string representing the canonical name of the encoding.
 
 Predefined As:
 
-  sub renew { return $_[0] }
+  sub renew {
+    my $self = shift;
+    my $clone = bless { %$self } => ref($self);
+    $clone->{renewed}++;
+    return $clone;
+  }
 
 This method reconstructs the encoding object if necessary.  If you need
 to store the state during encoding, this is where you clone your object.
-Here is an example:
-
-  sub renew { 
-      my $self = shift;
-      my $clone = bless { %$self } => ref($self);
-      $clone->{clone} = 1; # so the caller can see it
-      return $clone;
-  }
-
-Since most encodings are stateless the default behavior is just return
-itself as shown above.
 
 PerlIO ALWAYS calls this method to make sure it has its own private
 encoding object.
 
+=item -E<gt>renewed
+
+Predefined As:
+
+  sub renewed { $_[0]->{renewed} || 0 }
+
+Tells whether the object is renewed (and how many times).  Some
+modules emit C<Use of uninitialized value in null operation> warning
+unless the value is numeric so return 0 for false.
+
 =item -E<gt>perlio_ok()
 
 Predefined As:
